==> eam-wshub-proxyclient-11.4-14-sources.jar: org/openapplications/oagis_segments/TIME.java <==

package org.openapplications.oagis_segments;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TIME_Type;


/**
 * <p>Classe Java pour TIME complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="TIME">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}HOUR"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}MINUTE"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}SECOND"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}SUBSECOND"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TIME", propOrder = {
    "hour",
    "minute",
    "second",
    "subsecond"
})
@XmlSeeAlso({
    TIME_Type.class
})
public class TIME {

    @XmlElement(name = "HOUR", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger hour;
    @XmlElement(name = "MINUTE", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger minute;
    @XmlElement(name = "SECOND", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger second;
    @XmlElement(name = "SUBSECOND", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger subsecond;

    /**
     * Obtient la valeur de la propriété hour.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getHOUR() {
        return hour;
    }

    /**
     * Définit la valeur de la propriété hour.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setHOUR(BigInteger value) {
        this.hour = value;
    }

    /**
     * Obtient la valeur de la propriété minute.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getMINUTE() {
        return minute;
    }

    /**
     * Définit la valeur de la propriété minute.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setMINUTE(BigInteger value) {
        this.minute = value;
    }

    /**
     * Obtient la valeur de la propriété second.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSECOND() {
        return second;
    }

    /**
     * Définit la valeur de la propriété second.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSECOND(BigInteger value) {
        this.second = value;
    }

    /**
     * Obtient la valeur de la propriété subsecond.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSUBSECOND() {
        return subsecond;
    }

    /**
     * Définit la valeur de la propriété subsecond.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSUBSECOND(BigInteger value) {
        this.subsecond = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: org/openapplications/oagis_segments/TIME.java <==

package org.openapplications.oagis_segments;

import java.math.BigInteger;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.TIME_Type;


/**
 * <p>Java class for TIME complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TIME">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}HOUR"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}MINUTE"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}SECOND"/>
 *         &lt;element ref="{http://www.openapplications.org/oagis_fields}SUBSECOND"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TIME", propOrder = {
    "hour",
    "minute",
    "second",
    "subsecond"
})
@XmlSeeAlso({
    TIME_Type.class
})
public class TIME {

    @XmlElement(name = "HOUR", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger hour;
    @XmlElement(name = "MINUTE", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger minute;
    @XmlElement(name = "SECOND", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger second;
    @XmlElement(name = "SUBSECOND", namespace = "http://www.openapplications.org/oagis_fields", required = true)
    protected BigInteger subsecond;

    /**
     * Gets the value of the hour property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getHOUR() {
        return hour;
    }

    /**
     * Sets the value of the hour property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setHOUR(BigInteger value) {
        this.hour = value;
    }

    /**
     * Gets the value of the minute property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getMINUTE() {
        return minute;
    }

    /**
     * Sets the value of the minute property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setMINUTE(BigInteger value) {
        this.minute = value;
    }

    /**
     * Gets the value of the second property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSECOND() {
        return second;
    }

    /**
     * Sets the value of the second property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSECOND(BigInteger value) {
        this.second = value;
    }

    /**
     * Gets the value of the subsecond property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getSUBSECOND() {
        return subsecond;
    }

    /**
     * Sets the value of the subsecond property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setSUBSECOND(BigInteger value) {
        this.subsecond = value;
    }

}
